@@ -1,14 +1,14 @@
 <?php
-function jumbotron_get_menu($name = "top", $parent = null, $recursive = true, $order = "position") {
+function jumbotron_get_menu($name = "top", $parent_id = null, $recursive = true, $order = "position") {
 	$html = "";
 	$name = db_escape ( $name );
 	$language = $_SESSION ["language"];
-	$sql = "SELECT id, systemname, access, redirection, title, alternate_title, menu_image, target FROM " . tbname ( "content" ) . " WHERE menu='$name' AND language = '$language' AND active = 1 AND `deleted_at` IS NULL AND hidden = 0 and parent ";
+	$sql = "SELECT id, slug, access, redirection, title, alternate_title, menu_image, target FROM " . tbname ( "content" ) . " WHERE menu='$name' AND language = '$language' AND active = 1 AND `deleted_at` IS NULL AND hidden = 0 and parent_id ";
 	
-	if (is_null ( $parent )) {
+	if (is_null ( $parent_id )) {
 		$sql .= " IS NULL ";
 	} else {
-		$sql .= " = " . intval ( $parent ) . " ";
+		$sql .= " = " . intval ( $parent_id ) . " ";
 	}
 	$sql .= " ORDER by " . $order;
 	$query = db_query ( $sql );
@@ -17,10 +17,10 @@ function jumbotron_get_menu($name = "top", $parent = null, $recursive = true, $o
 		return $html;
 	}
 	
-	if (is_null ( $parent )) {
+	if (is_null ( $parent_id )) {
 		$html .= "<ul class='nav nav-pills pull-right menu_top'>\n";
 	} else {
-		$containsCurrentItem = parent_item_contains_current_page ( $parent );
+		$containsCurrentItem = parent_item_contains_current_page ( $parent_id );
 		
 		$classes = "sub_menu";
 		
@@ -39,7 +39,7 @@ function jumbotron_get_menu($name = "top", $parent = null, $recursive = true, $o
 				$additional_classes .= "active ";
 			}
 			
-			if (get_requested_pagename () != $row->systemname) {
+			if (get_requested_pagename () != $row->slug) {
 				$html .= "  <li class='" . trim ( $additional_classes ) . "'>";
 			} else {
 				$html .= "  <li class='active" . rtrim ( $additional_classes ) . "'>";
@@ -49,10 +49,10 @@ function jumbotron_get_menu($name = "top", $parent = null, $recursive = true, $o
 			} else {
 				$title = $row->title;
 			}
-			if (get_requested_pagename () != $row->systemname) {
-				$html .= "<a href='" . buildSEOUrl ( $row->systemname, $row->redirection ) . "' target='" . $row->target . "' class='" . trim ( $additional_classes ) . "'>";
+			if (get_requested_pagename () != $row->slug) {
+				$html .= "<a href='" . buildSEOUrl ( $row->slug, $row->redirection ) . "' target='" . $row->target . "' class='" . trim ( $additional_classes ) . "'>";
 			} else {
-				$html .= "<a class='active" . rtrim ( $additional_classes ) . "' href='" . buildSEOUrl ( $row->systemname, $row->redirection ) . "' target='" . $row->target . "'>";
+				$html .= "<a class='active" . rtrim ( $additional_classes ) . "' href='" . buildSEOUrl ( $row->slug, $row->redirection ) . "' target='" . $row->target . "'>";
 			}
 			if (! is_null ( $row->menu_image ) and ! empty ( $row->menu_image )) {
 				$html .= '<img src="' . $row->menu_image . '" alt="' . htmlentities ( $row->title, ENT_QUOTES, "UTF-8" ) . '"/>';
